# QHBM Library

This repository is a collection of tools for building and training
Quantum Hamiltonian-Based Models.  These tools depend on
[TensorFlow Quantum](https://www.tensorflow.org/quantum),
and are thus compatible with both real and simulated quantum computers.

[Installation instructions](https://github.com/google/qhbm-library/blob/main/docs/INSTALL.md) and [contribution instructions](https://github.com/google/qhbm-library/blob/main/docs/contributing.md) can be found in the docs folder.

This is not an officially supported Google product.
